SliderDrawerOption class

Constructors

SliderDrawerOption({Color backgroundColor = Colors.blue, SliderEffectType sliderEffectType = SliderEffectType.Rectangle, Image? backgroundImage, double radiusAmount = 0, double upDownScaleAmount = 0, SliderDrawerDirection direction = SliderDrawerDirection.LTR})

Properties

backgroundColor → Color
final
backgroundImage → Image?
final
direction → SliderDrawerDirection
final
hashCode → int
The hash code for this object.
no setterinherited
radiusAmount → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliderEffectType → SliderEffectType
final
upDownScaleAmount → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited