SliderDrawerWidgetState class

Inheritance
Mixed-in types

Constructors

SliderDrawerWidgetState()

Properties

animationController ↔ AnimationController
getter/setter pair
backgroundDecorationAlignment ↔ Alignment
getter/setter pair
backgroundDrawerAlignment ↔ Alignment
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
dragPossible ↔ bool
getter/setter pair
drawerPadding ↔ EdgeInsetsGeometry
getter/setter pair
drawerPosition → double
no setter
drawerRate ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isOpened ↔ bool
getter/setter pair
limitPercent ↔ double
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
option ↔ SliderDrawerOption
getter/setter pair
radiusAmount ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ Size
getter/setter pair
upDownScaleAmount ↔ double
getter/setter pair
widget → SliderDrawerWidget
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
closeDrawer() → void
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didUpdateWidget(covariant SliderDrawerWidget oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
inherited
initState() → void
Called when this object is inserted into the tree.
override
loadBackgroundDecoration() → BoxDecoration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDrawer() → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toggleDrawer() → void
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
update() → void
updateDrawerRate(double rate) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited